@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2011 Red Hat, Inc.
+ * Copyright (c) 2011, 2013 Red Hat, Inc.
  *
  * Gnome Documents is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by the
@@ -58,7 +58,10 @@ account_miner_job_process_entry (GdAccountMinerJob *job,
 
   if (GDATA_IS_DOCUMENTS_FOLDER (doc_entry))
     {
-      identifier = g_strdup_printf ("gd:collection:%s", gdata_entry_get_id (entry));
+      GDataLink *link;
+
+      link = gdata_entry_look_up_link (entry, GDATA_LINK_SELF);
+      identifier = g_strdup_printf ("gd:collection:%s", gdata_link_get_uri (link));
       resource_url = NULL;
     }
   else
@@ -92,7 +95,7 @@ account_miner_job_process_entry (GdAccountMinerJob *job,
     (job->connection,
      job->cancellable, error,
      &resource_exists,
-     resource_url, identifier,
+     job->datasource_urn, identifier,
      "nfo:RemoteDataObject", class, NULL);
 
   if (*error != NULL)
@@ -126,7 +129,7 @@ account_miner_job_process_entry (GdAccountMinerJob *job,
   gd_miner_tracker_sparql_connection_insert_or_replace_triple
     (job->connection,
      job->cancellable, error,
-     identifier, resource,
+     job->datasource_urn, resource,
      "nie:url", alternate_uri);
 
   if (*error != NULL)
@@ -141,7 +144,7 @@ account_miner_job_process_entry (GdAccountMinerJob *job,
   gd_miner_tracker_sparql_connection_insert_or_replace_triple
     (job->connection,
      job->cancellable, error,
-     identifier, resource,
+     job->datasource_urn, resource,
      "nie:mimeType", mimetype_override);
 
   if (*error != NULL)
@@ -158,7 +161,8 @@ account_miner_job_process_entry (GdAccountMinerJob *job,
 
       parent_resource_urn = gd_miner_tracker_sparql_connection_ensure_resource
         (job->connection, job->cancellable, error,
-         NULL, parent_resource_id,
+         NULL,
+         job->datasource_urn, parent_resource_id,
          "nfo:RemoteDataObject", "nfo:DataContainer", NULL);
       g_free (parent_resource_id);
 
@@ -168,7 +172,7 @@ account_miner_job_process_entry (GdAccountMinerJob *job,
       gd_miner_tracker_sparql_connection_insert_or_replace_triple
         (job->connection,
          job->cancellable, error,
-         identifier, resource,
+         job->datasource_urn, resource,
          "nie:isPartOf", parent_resource_urn);
       g_free (parent_resource_urn);
 
@@ -198,7 +202,7 @@ account_miner_job_process_entry (GdAccountMinerJob *job,
   gd_miner_tracker_sparql_connection_insert_or_replace_triple
     (job->connection,
      job->cancellable, error,
-     identifier, resource,
+     job->datasource_urn, resource,
      "nie:description", gdata_entry_get_summary (entry));
 
   if (*error != NULL)
@@ -207,7 +211,7 @@ account_miner_job_process_entry (GdAccountMinerJob *job,
   gd_miner_tracker_sparql_connection_insert_or_replace_triple
     (job->connection,
      job->cancellable, error,
-     identifier, resource,
+     job->datasource_urn, resource,
      "nie:title", gdata_entry_get_title (entry));
 
   if (*error != NULL)
@@ -231,7 +235,7 @@ account_miner_job_process_entry (GdAccountMinerJob *job,
       gd_miner_tracker_sparql_connection_insert_or_replace_triple
         (job->connection,
          job->cancellable, error,
-         identifier, resource,
+         job->datasource_urn, resource,
          "nco:creator", contact_resource);
 
       if (*error != NULL)
@@ -273,7 +277,7 @@ account_miner_job_process_entry (GdAccountMinerJob *job,
       gd_miner_tracker_sparql_connection_insert_or_replace_triple
         (job->connection,
          job->cancellable, error,
-         identifier, resource,
+         job->datasource_urn, resource,
          "nco:contributor", contact_resource);
 
       g_free (contact_resource);
@@ -286,7 +290,7 @@ account_miner_job_process_entry (GdAccountMinerJob *job,
   gd_miner_tracker_sparql_connection_insert_or_replace_triple
     (job->connection,
      job->cancellable, error,
-     identifier, resource,
+     job->datasource_urn, resource,
      "nie:contentCreated", date);
   g_free (date);
 
@@ -369,7 +373,7 @@ gd_gdata_miner_class_init (GdGDataMinerClass *klass)
 
   miner_class->goa_provider_type = "google";
   miner_class->miner_identifier = MINER_IDENTIFIER;
-  miner_class->version = 2;
+  miner_class->version = 3;
 
   miner_class->create_service = create_service;
   miner_class->query = query_gdata;
