@@ -272,6 +272,7 @@ const OverviewSearchbar = new Lang.Class({
 
     _init: function(dropdown) {
         this._dropdown = dropdown;
+        this._selectAll = Application.application.lookup_action('select-all');
 
         this.parent();
 
@@ -298,15 +299,13 @@ const OverviewSearchbar = new Lang.Class({
             Lang.bind(this, this._onTagClicked));
 
         // connect to search string changes in the controller
-        let searchChangedId = Application.searchController.connect('search-string-changed', Lang.bind(this,
-            function(controller, string) {
-                this._searchEntry.set_text(string);
-            }));
+        this._searchChangedId = Application.searchController.connect('search-string-changed',
+            Lang.bind(this, this._onSearchStringChanged));
 
         this._searchEntry.connect('destroy', Lang.bind(this,
             function() {
                 this._dropdown.widget.reveal_child = false;
-                Application.searchController.disconnect(searchChangedId);
+                Application.searchController.disconnect(this._searchChangedId);
             }));
 
         // create the dropdown button
@@ -335,7 +334,17 @@ const OverviewSearchbar = new Lang.Class({
 
     entryChanged: function() {
         let currentText = this._searchEntry.get_text().toLowerCase();
+
+        Application.searchController.disconnect(this._searchChangedId);
         Application.searchController.setString(currentText);
+
+        // connect to search string changes in the controller
+        this._searchChangedId = Application.searchController.connect('search-string-changed',
+            Lang.bind(this, this._onSearchStringChanged));
+    },
+
+    _onSearchStringChanged: function(controller, string) {
+        this._searchEntry.set_text(string);
     },
 
     _onActiveCollectionChanged: function() {
@@ -407,8 +416,14 @@ const OverviewSearchbar = new Lang.Class({
         this.parent();
     },
 
+    show: function() {
+        this._selectAll.enabled = false;
+        this.parent();
+    },
+
     hide: function() {
         this._dropdownButton.set_active(false);
+        this._selectAll.enabled = true;
 
         Application.searchTypeManager.setActiveItemById('all');
         Application.searchMatchManager.setActiveItemById('all');
